#!/usr/bin/env python3

import os
from flask import Flask, flash, request, redirect, url_for
from werkzeug.utils import secure_filename
from flask import send_from_directory
import hashlib
import mariadb

conn = mariadb.connect(
    user="root",
    password="mysqllt38c",
    host="localhost",
    database="lt38c")
conn.autocommit = False
cur = conn.cursor()


UPLOAD_FOLDER = '/tmp'

IMAGE_EXTENSIONS = {'hex', 'elf'}
SKETCH_EXTENSIONS = {'ino', 'zip'}
ALLOWED_EXTENSIONS = IMAGE_EXTENSIONS | SKETCH_EXTENSIONS

app = Flask(__name__)
app.secret_key = b')\xec~t\xb7d\xfc\xa1\xea>*\xba!\x15\xcc}'
app.config['UPLOAD_FOLDER'] = UPLOAD_FOLDER


def to_db(version, firmware, hash, email):
    table = 'arduino'
    query = f'INSERT INTO {table} (versao,firmware,email,md5sum) VALUES (?,?,?,?)'
    cur.execute(query, (version,firmware,email,hash))
    conn.commit()


def accept(file, version='0.0', email='muralha@utfpr.edu.br'):
    file_content = file.read()
    md5 = hashlib.md5(file_content).hexdigest()
    to_db(version, file_content, md5, email)


def allowed_file(filename):
    return '.' in filename and filename.rsplit('.', 1)[1].lower() in ALLOWED_EXTENSIONS


@app.route('/', methods=['GET', 'POST'])
def upload_file():
    if request.method == 'POST':
        # check if the post request has the file part
        if 'file' not in request.files:
            flash('No file part')
            return redirect(request.url)
        file = request.files['file']
        # if user does not select file, browser also
        # submit an empty part without filename
        if file.filename == '':
            flash('No selected file')
            return redirect(request.url)
        if not allowed_file(file.filename):
            flash('Extension not allowed')
            return redirect(request.url)
        if file and allowed_file(file.filename):
            accept(file,request.form['version'],request.form['email'])
            file.seek(0)
            filename = secure_filename(file.filename)
            file.save(os.path.join(app.config['UPLOAD_FOLDER'], filename))
            return redirect(url_for('uploaded_file',
                                    filename=filename))

    return '''
    <!doctype html>
    <title>Upload new File</title>
    <h1>Upload new File</h1>
    <form method=post enctype=multipart/form-data>
      <input type="file" name="file">
	  <label for="version">Version:</label>
	  <input type="text" name="version">
	  <label for="email">Email:</label>
	  <input type="email", name="email">
      <input type="submit" value="Upload">
    </form>
    '''


@app.route('/uploads/<filename>')
def uploaded_file(filename):
        return send_from_directory(app.config['UPLOAD_FOLDER'], filename)


if __name__ == '__main__':
    app.run(host='0.0.0.0', debug=True)